@@ -180,11 +180,21 @@ class TerminalPlugin(SpyderPluginWidget):
         message = ''
         valid = True
         if PYQT4 or PYSIDE:
-            message = _('This plugin does not work with Qt 4')
-            valid = False
-        elif WINDOWS and PY2:
-            message = _('This plugin does not work with Python 2 on Windows')
+            message = _('<b>spyder-terminal</b> doesn\'t work with Qt 4. '
+                        'Therefore, this plugin will be deactivated.')
             valid = False
+        if WINDOWS:
+            try:
+                import winpty
+                del winpty
+            except:
+                message = _('Unfortunately, the library that <b>spyder-termina'
+                            'l</b> uses to create terminals is failing to '
+                            'work in your system. Therefore, this plugin will '
+                            'be deactivated.<br><br> This usually happens on '
+                            'Windows 7 systems. If that\'s the case, please '
+                            'consider updating to a newer Windows version.')
+                valid = False
         return valid, message
 
     # ------ SpyderPluginWidget API ------------------------------
